@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import Dict
 
-from dagster import check
+import dagster._check as check
 
 from .config_type import ConfigType
 from .field import Field
@@ -72,6 +72,24 @@ class ValidationContext(ContextData):
             stack=self.stack.for_array_index(index),
         )
 
+    def for_map_key(self, key: object) -> "ValidationContext":
+        return ValidationContext(
+            config_schema_snapshot=self.config_schema_snapshot,
+            config_type_snap=self.config_schema_snapshot.get_config_snap(
+                self.config_type_snap.key_type_key
+            ),
+            stack=self.stack.for_map_key(key),
+        )
+
+    def for_map_value(self, key: object) -> "ValidationContext":
+        return ValidationContext(
+            config_schema_snapshot=self.config_schema_snapshot,
+            config_type_snap=self.config_schema_snapshot.get_config_snap(
+                self.config_type_snap.inner_type_key
+            ),
+            stack=self.stack.for_map_value(key),
+        )
+
     def for_new_config_type_key(self, config_type_key: str) -> "ValidationContext":
         check.str_param(config_type_key, "config_type_key")
         return ValidationContext(
@@ -157,6 +175,18 @@ class TraversalContext(ContextData):
             all_config_types=self.all_config_types,
         )
 
+    def for_map(self, key: object) -> "TraversalContext":
+        return TraversalContext(
+            config_schema_snapshot=self.config_schema_snapshot,
+            config_type_snap=self.config_schema_snapshot.get_config_snap(
+                self.config_type_snap.inner_type_key
+            ),
+            config_type=self.config_type.inner_type,  # type: ignore
+            stack=self.stack.for_map_value(key),
+            traversal_type=self.traversal_type,
+            all_config_types=self.all_config_types,
+        )
+
     def for_field(self, field_def: Field, field_name: str) -> "TraversalContext":
         check.inst_param(field_def, "field_def", Field)
         check.str_param(field_name, "field_name")
