@@ -15,7 +15,7 @@ from typing import (
     cast,
 )
 
-from dagster import check
+import dagster._check as check
 from dagster.core.definitions.policy import RetryPolicy
 from dagster.core.errors import DagsterInvalidDefinitionError
 from dagster.serdes.serdes import (
@@ -67,6 +67,7 @@ class NodeInvocation(
     :py:func:`@job <job>` API:
 
     .. code-block:: python
+
         from dagster import job
 
         @job
