@@ -1,13 +1,15 @@
-from abc import ABCMeta, abstractmethod
+from abc import ABC, abstractmethod
+from typing import TYPE_CHECKING, FrozenSet, List, Optional
 
-import six
-
-from dagster import check
+import dagster._check as check
 from dagster.core.errors import DagsterInvalidSubsetError
 from dagster.core.selector import parse_solid_selection
 
+if TYPE_CHECKING:
+    from .pipeline_definition import PipelineDefinition
 
-class IPipeline(six.with_metaclass(ABCMeta)):
+
+class IPipeline(ABC):
     """
     IPipeline is a wrapper interface for PipelineDefinitions to be used as parameters to Dagster's
     core execution APIs.  This enables these execution APIs to operate on both in memory pipeline
@@ -16,11 +18,22 @@ class IPipeline(six.with_metaclass(ABCMeta)):
     """
 
     @abstractmethod
-    def get_definition(self):
+    def get_definition(self) -> "PipelineDefinition":
         pass
 
     @abstractmethod
-    def subset_for_execution(self, solid_selection):
+    def subset_for_execution(self, solid_selection: List[str]) -> "IPipeline":
+        pass
+
+    @property
+    @abstractmethod
+    def solids_to_execute(self) -> Optional[FrozenSet[str]]:
+        pass
+
+    @abstractmethod
+    def subset_for_execution_from_existing_pipeline(
+        self, solids_to_execute: Optional[FrozenSet[str]]
+    ) -> "IPipeline":
         pass
 
 
@@ -39,9 +52,11 @@ class InMemoryPipeline(IPipeline, object):
         check.list_param(solid_selection, "solid_selection", of_type=str)
         solids_to_execute = parse_solid_selection(self.get_definition(), solid_selection)
         if len(solids_to_execute) == 0:
+            node_type = "ops" if self._pipeline_def.is_job else "solids"
+            selection_type = "op_selection" if self._pipeline_def.is_job else "solid_selection"
             raise DagsterInvalidSubsetError(
-                "No qualified solids to execute found for solid_selection={requested}".format(
-                    requested=solid_selection
+                "No qualified {node_type} to execute found for {selection_type}={requested}".format(
+                    node_type=node_type, requested=solid_selection, selection_type=selection_type
                 )
             )
         return solids_to_execute
@@ -75,11 +90,11 @@ class InMemoryPipeline(IPipeline, object):
         return self._subset_for_execution(solids_to_execute)
 
     @property
-    def solid_selection(self):
+    def solid_selection(self) -> List[str]:
         # a list of solid queries provided by the user
         return self._solid_selection  # List[str]
 
     @property
-    def solids_to_execute(self):
+    def solids_to_execute(self) -> FrozenSet[str]:
         # a frozenset which contains the names of the solids to execute
         return self._solids_to_execute  # FrozenSet[str]
