@@ -1,10 +1,10 @@
 from typing import Any, Dict, List, Optional, Union, cast
 
-from dagster import check
+import dagster._check as check
 from dagster.core.definitions import NodeDefinition, NodeHandle
 from dagster.core.definitions.events import AssetMaterialization, AssetObservation, Materialization
 from dagster.core.definitions.utils import DEFAULT_OUTPUT
-from dagster.core.errors import DagsterInvariantViolationError
+from dagster.core.errors import DagsterError, DagsterInvariantViolationError
 from dagster.core.events import (
     AssetObservationData,
     DagsterEvent,
@@ -12,6 +12,7 @@ from dagster.core.events import (
     StepMaterializationData,
 )
 from dagster.core.execution.plan.outputs import StepOutputHandle
+from dagster.core.storage.pipeline_run import DagsterRun
 
 
 class ExecuteInProcessResult:
@@ -19,7 +20,7 @@ class ExecuteInProcessResult:
         self,
         node_def: NodeDefinition,
         all_events: List[DagsterEvent],
-        run_id: str,
+        dagster_run: DagsterRun,
         output_capture: Optional[Dict[StepOutputHandle, Any]],
     ):
         self._node_def = node_def
@@ -27,7 +28,7 @@ class ExecuteInProcessResult:
         # If top-level result, no handle will be provided
         self._handle = NodeHandle(node_def.name, parent=None)
         self._event_list = all_events
-        self._run_id = run_id
+        self._dagster_run = dagster_run
 
         self._output_capture = check.opt_dict_param(
             output_capture, "output_capture", key_type=StepOutputHandle
@@ -36,7 +37,7 @@ class ExecuteInProcessResult:
     @property
     def success(self) -> bool:
         """bool: Whether execution was successful."""
-        return all([not event.is_failure for event in self._event_list])
+        return self._dagster_run.is_success
 
     @property
     def all_node_events(self) -> List[DagsterEvent]:
@@ -50,10 +51,21 @@ class ExecuteInProcessResult:
 
         return step_events
 
+    @property
+    def all_events(self) -> List[DagsterEvent]:
+        """List[DagsterEvent]: All dagster events emitted during in-process execution."""
+
+        return self._event_list
+
     @property
     def run_id(self) -> str:
         """str: The run id for the executed run"""
-        return self._run_id
+        return self._dagster_run.run_id
+
+    @property
+    def dagster_run(self) -> DagsterRun:
+        """DagsterRun: the DagsterRun object for the completed execution."""
+        return self._dagster_run
 
     def events_for_node(self, node_name: str) -> List[DagsterEvent]:
         """Retrieves all dagster events for a specific node.
@@ -147,6 +159,36 @@ class ExecuteInProcessResult:
             self._output_capture, origin_handle, origin_output_def.name
         )
 
+    def get_job_success_event(self):
+        """Returns a DagsterEvent with type DagsterEventType.PIPELINE_SUCCESS if it ocurred during
+        execution
+        """
+        events = list(
+            filter(
+                lambda event: event.event_type == DagsterEventType.PIPELINE_SUCCESS, self.all_events
+            )
+        )
+
+        if len(events) == 0:
+            raise DagsterError("No event of type DagsterEventType.PIPELINE_SUCCESS found.")
+
+        return events[0]
+
+    def get_job_failure_event(self):
+        """Returns a DagsterEvent with type DagsterEventType.PIPELINE_FAILURE if it ocurred during
+        execution
+        """
+        events = list(
+            filter(
+                lambda event: event.event_type == DagsterEventType.PIPELINE_FAILURE, self.all_events
+            )
+        )
+
+        if len(events) == 0:
+            raise DagsterError("No event of type DagsterEventType.PIPELINE_FAILURE found.")
+
+        return events[0]
+
 
 def _filter_events_by_handle(
     event_list: List[DagsterEvent], handle: NodeHandle
@@ -175,7 +217,10 @@ def _filter_outputs_by_handle(
 
         # For the mapped output case, where step keys are in the format
         # "step_key[upstream_mapped_output_name]" within the step output handle.
-        if step_output_handle.step_key.startswith(f"{step_key}["):
+        if (
+            step_output_handle.step_key.startswith(f"{step_key}[")
+            and step_output_handle.output_name == output_name
+        ):
             output_found = True
             key_start = step_output_handle.step_key.find("[")
             key_end = step_output_handle.step_key.find("]")
