@@ -14,7 +14,7 @@ from typing import (
     cast,
 )
 
-from dagster import check
+import dagster._check as check
 from dagster.core.definitions.utils import validate_tags
 from dagster.serdes.serdes import DefaultEnumSerializer, whitelist_for_serdes
 from dagster.utils import merge_dicts
