@@ -2,7 +2,7 @@ import warnings
 from collections import OrderedDict
 from typing import TYPE_CHECKING, List, Optional, Sequence, Union
 
-from dagster import check
+import dagster._check as check
 from dagster.core.definitions.events import AssetKey
 from dagster.core.definitions.run_request import InstigatorType
 from dagster.core.definitions.schedule_definition import DefaultScheduleStatus
@@ -700,6 +700,10 @@ class ExternalPartitionSet:
     def pipeline_name(self):
         return self._external_partition_set_data.pipeline_name
 
+    @property
+    def repository_handle(self):
+        return self._handle.repository_handle
+
     def get_external_origin(self):
         return self._handle.get_external_origin()
 
