@@ -1,7 +1,8 @@
 import os
 import warnings
 
-from dagster import Array, Bool, check
+from dagster import Array, Bool
+from dagster import _check as check
 from dagster.config import Field, Permissive
 from dagster.config.validate import validate_config
 from dagster.core.errors import DagsterInvalidConfigError
