@@ -3,7 +3,7 @@ from typing import Dict, NamedTuple, Optional
 
 import yaml
 
-from dagster import check
+import dagster._check as check
 from dagster.serdes import ConfigurableClassData, class_from_code_pointer, whitelist_for_serdes
 
 from .config import DAGSTER_CONFIG_YAML_FILENAME, dagster_instance_config
