@@ -1,13 +1,15 @@
 import time
 
-import grpc
-from dagster import Bool, Field, check, seven
-from dagster.core.errors import DagsterLaunchFailedError
-from dagster.core.host_representation import ExternalPipeline
-from dagster.core.host_representation.handle import (
-    GrpcServerRepositoryLocationHandle,
-    ManagedGrpcPythonEnvRepositoryLocationHandle,
+import dagster.seven as seven
+from dagster import Bool, Field
+from dagster import _check as check
+from dagster.core.errors import (
+    DagsterInvariantViolationError,
+    DagsterLaunchFailedError,
+    DagsterUserCodeUnreachableError,
 )
+from dagster.core.host_representation.grpc_server_registry import ProcessGrpcServerRegistry
+from dagster.core.host_representation.repository_location import GrpcServerRepositoryLocation
 from dagster.core.storage.pipeline_run import PipelineRun
 from dagster.core.storage.tags import GRPC_INFO_TAG
 from dagster.grpc.client import DagsterGrpcClient
@@ -15,16 +17,12 @@ from dagster.grpc.types import (
     CanCancelExecutionRequest,
     CancelExecutionRequest,
     ExecuteExternalPipelineArgs,
+    StartRunResult,
 )
-from dagster.serdes import ConfigurableClass
+from dagster.serdes import ConfigurableClass, deserialize_as, deserialize_json_to_dagster_namedtuple
 from dagster.utils import merge_dicts
 
-from .base import RunLauncher
-
-GRPC_REPOSITORY_LOCATION_HANDLE_TYPES = (
-    GrpcServerRepositoryLocationHandle,
-    ManagedGrpcPythonEnvRepositoryLocationHandle,
-)
+from .base import LaunchRunContext, RunLauncher
 
 
 class DefaultRunLauncher(RunLauncher, ConfigurableClass):
@@ -41,7 +39,7 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
 
         self._run_ids = set()
 
-        self._processes_to_wait_for = []
+        self._locations_to_wait_for = []
 
         super().__init__()
 
@@ -59,43 +57,35 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
             inst_data=inst_data, wait_for_processes=config_value.get("wait_for_processes", False)
         )
 
-    def launch_run(self, run, external_pipeline):
-        check.inst_param(run, "run", PipelineRun)
-        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
-
-        repository_location_handle = external_pipeline.repository_handle.repository_location_handle
-
-        check.inst(
-            repository_location_handle,
-            GRPC_REPOSITORY_LOCATION_HANDLE_TYPES,
-            "DefaultRunLauncher: Can't launch runs for pipeline not loaded from a GRPC server",
-        )
-
-        self._instance.add_run_tags(
+    @staticmethod
+    def launch_run_from_grpc_client(instance, run, grpc_client):
+        instance.add_run_tags(
             run.run_id,
             {
                 GRPC_INFO_TAG: seven.json.dumps(
                     merge_dicts(
-                        {"host": repository_location_handle.host},
+                        {"host": grpc_client.host},
                         (
-                            {"port": repository_location_handle.port}
-                            if repository_location_handle.port
-                            else {"socket": repository_location_handle.socket}
+                            {"port": grpc_client.port}
+                            if grpc_client.port
+                            else {"socket": grpc_client.socket}
                         ),
-                        ({"use_ssl": True} if repository_location_handle.use_ssl else {}),
+                        ({"use_ssl": True} if grpc_client.use_ssl else {}),
                     )
                 )
             },
         )
 
-        res = repository_location_handle.client.start_run(
-            ExecuteExternalPipelineArgs(
-                pipeline_origin=external_pipeline.get_external_origin(),
-                pipeline_run_id=run.run_id,
-                instance_ref=self._instance.get_ref(),
-            )
+        res = deserialize_as(
+            grpc_client.start_run(
+                ExecuteExternalPipelineArgs(
+                    pipeline_origin=run.external_pipeline_origin,
+                    pipeline_run_id=run.run_id,
+                    instance_ref=instance.get_ref(),
+                )
+            ),
+            StartRunResult,
         )
-
         if not res.success:
             raise (
                 DagsterLaunchFailedError(
@@ -103,14 +93,35 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
                 )
             )
 
+    def launch_run(self, context: LaunchRunContext) -> None:
+        run = context.pipeline_run
+
+        check.inst_param(run, "run", PipelineRun)
+
+        if not context.workspace:
+            raise DagsterInvariantViolationError(
+                "DefaultRunLauncher requires a workspace to be included in its LaunchRunContext"
+            )
+
+        external_pipeline_origin = check.not_none(run.external_pipeline_origin)
+        repository_location = context.workspace.get_location(
+            external_pipeline_origin.external_repository_origin.repository_location_origin.location_name
+        )
+
+        check.inst(
+            repository_location,
+            GrpcServerRepositoryLocation,
+            "DefaultRunLauncher: Can't launch runs for pipeline not loaded from a GRPC server",
+        )
+
+        DefaultRunLauncher.launch_run_from_grpc_client(
+            self._instance, run, repository_location.client
+        )
+
         self._run_ids.add(run.run_id)
 
-        if self._wait_for_processes and isinstance(
-            repository_location_handle, ManagedGrpcPythonEnvRepositoryLocationHandle
-        ):
-            self._processes_to_wait_for.append(repository_location_handle.grpc_server_process)
-
-        return run
+        if self._wait_for_processes:
+            self._locations_to_wait_for.append(repository_location)
 
     def _get_grpc_client_for_termination(self, run_id):
         if not self._instance:
@@ -142,8 +153,10 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
             return False
 
         try:
-            res = client.can_cancel_execution(CanCancelExecutionRequest(run_id=run_id), timeout=5)
-        except grpc._channel._InactiveRpcError:  # pylint: disable=protected-access
+            res = deserialize_json_to_dagster_namedtuple(
+                client.can_cancel_execution(CanCancelExecutionRequest(run_id=run_id), timeout=5)
+            )
+        except DagsterUserCodeUnreachableError:
             # Server that created the run may no longer exist
             return False
 
@@ -169,7 +182,9 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
             return False
 
         self._instance.report_run_canceling(run)
-        res = client.cancel_execution(CancelExecutionRequest(run_id=run_id))
+        res = deserialize_json_to_dagster_namedtuple(
+            client.cancel_execution(CancelExecutionRequest(run_id=run_id))
+        )
         return res.success
 
     def join(self, timeout=30):
@@ -208,5 +223,8 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
         if not self._wait_for_processes:
             return
 
-        for process in self._processes_to_wait_for:
-            process.wait()
+        for location in self._locations_to_wait_for:
+            if isinstance(location, GrpcServerRepositoryLocation) and isinstance(
+                location.grpc_server_registry, ProcessGrpcServerRegistry
+            ):
+                location.grpc_server_registry.wait_for_processes()
