@@ -4,7 +4,7 @@ import sqlalchemy as db
 from alembic import op
 from sqlalchemy.engine import reflection
 
-from dagster import check
+import dagster._check as check
 from dagster.core.storage.sql import get_current_timestamp
 
 
@@ -200,6 +200,10 @@ def create_event_log_event_idx():
     if not has_table("event_logs"):
         return
 
+    indices = [x.get("name") for x in get_inspector().get_indexes("event_logs")]
+    if "idx_event_type" in indices:
+        return
+
     op.create_index(
         "idx_event_type",
         "event_logs",
